TypeCode

Enum TypeCode 

pub enum TypeCode {
    Unspecified = 0,
    Bool = 1,
    Int64 = 2,
    Float64 = 3,
    Timestamp = 4,
    Date = 5,
    String = 6,
    Bytes = 7,
    Array = 8,
    Struct = 9,
}
TypeCode is used as part of [Type][google.spanner.v1.Type] to indicate the type of a Cloud Spanner value.

Each legal value of a type can be encoded to or decoded from a JSON value, using the encodings described below. All Cloud Spanner values can be null, regardless of type; nulls are always encoded as a JSON null.

Variants



Unspecified = 0

Not specified.



Bool = 1

Encoded as JSON true or false.



Int64 = 2

Encoded as string, in decimal format.



Float64 = 3

Encoded as number, or the strings "NaN", "Infinity", or "-Infinity".



Timestamp = 4

Encoded as string in RFC 3339 timestamp format. The time zone must be present, and must be "Z".

If the schema has the column option allow_commit_timestamp=true, the placeholder string "spanner.commit_timestamp()" can be used to instruct the system to insert the commit timestamp associated with the transaction commit.



Date = 5

Encoded as string in RFC 3339 date format.



String = 6

Encoded as string.



Bytes = 7

Encoded as a base64-encoded string, as described in RFC 4648, section 4.



Array = 8

Encoded as list, where the list elements are represented according to [array_element_type][google.spanner.v1.Type.array_element_type].



Struct = 9

Encoded as list, where list element i is represented according to [struct_type.fields[i]][google.spanner.v1.StructType.fields].

Implementations

Source

impl TypeCode

pub fn is_valid(value: i32) -> bool

Returns true if value is a variant of TypeCode.

pub fn from_i32(value: i32) -> Option<TypeCode>

Converts an i32 to a TypeCode, or None if value is not a valid variant.