pub enum Kind {
Unspecified = 0,
Relational = 1,
Scalar = 2,
}Expand description
The kind of [PlanNode][google.spanner.v1.PlanNode]. Distinguishes between the two different kinds of nodes that can appear in a query plan.
Variants
Unspecified = 0
Not specified.
Relational = 1
Denotes a Relational operator node in the expression tree. Relational
operators represent iterative processing of rows during query execution.
For example, a TableScan operation that reads rows from a table.
Scalar = 2
Denotes a Scalar node in the expression tree. Scalar nodes represent non-iterable entities in the query plan. For example, constants or arithmetic operators appearing inside predicate expressions or references to column names.
Implementations