pub struct ReadRequest {
pub session: String,
pub transaction: Option<TransactionSelector>,
pub table: String,
pub index: String,
pub columns: Vec<String>,
pub key_set: Option<KeySet>,
pub limit: i64,
pub resume_token: Vec<u8>,
pub partition_token: Vec<u8>,
}Expand description
The request for [Read][google.spanner.v1.Spanner.Read] and [StreamingRead][google.spanner.v1.Spanner.StreamingRead].
Fields
session: StringRequired. The session in which the read should be performed.
transaction: Option<TransactionSelector>The transaction to use. If none is provided, the default is a temporary read-only transaction with strong concurrency.
table: StringRequired. The name of the table in the database to be read.
index: StringIf non-empty, the name of an index on [table][google.spanner.v1.ReadRequest.table]. This index is used instead of the table primary key when interpreting [key_set][google.spanner.v1.ReadRequest.key_set] and sorting result rows. See [key_set][google.spanner.v1.ReadRequest.key_set] for further information.
columns: Vec<String>The columns of [table][google.spanner.v1.ReadRequest.table] to be returned for each row matching this request.
key_set: Option<KeySet>Required. key_set identifies the rows to be yielded. key_set names the
primary keys of the rows in [table][google.spanner.v1.ReadRequest.table] to be yielded, unless [index][google.spanner.v1.ReadRequest.index]
is present. If [index][google.spanner.v1.ReadRequest.index] is present, then [key_set][google.spanner.v1.ReadRequest.key_set] instead names
index keys in [index][google.spanner.v1.ReadRequest.index].
If the [partition_token][google.spanner.v1.ReadRequest.partition_token] field is empty, rows are yielded in table primary key order (if [index][google.spanner.v1.ReadRequest.index] is empty) or index key order (if [index][google.spanner.v1.ReadRequest.index] is non-empty). If the [partition_token][google.spanner.v1.ReadRequest.partition_token] field is not empty, rows will be yielded in an unspecified order.
It is not an error for the key_set to name rows that do not
exist in the database. Read yields nothing for nonexistent rows.
limit: i64If greater than zero, only the first limit rows are yielded. If limit
is zero, the default is no limit. A limit cannot be specified if
partition_token is set.
resume_token: Vec<u8>If this request is resuming a previously interrupted read,
resume_token should be copied from the last
[PartialResultSet][google.spanner.v1.PartialResultSet] yielded before the interruption. Doing this
enables the new read to resume where the last read left off. The
rest of the request parameters must exactly match the request
that yielded this token.
partition_token: Vec<u8>If present, results will be restricted to the specified partition previously created using PartitionRead(). There must be an exact match for the values of fields common to this message and the PartitionReadRequest message used to create this partition_token.